@@ -119,6 +119,12 @@ def rdo_horizon_plugins_tr(mod):
     return (pkg, '', '')
 
 
+def suse_horizon_plugins_tr(mod):
+    mod = mod.replace('dashboard', 'ui')
+    pkg = 'openstack-horizon-plugin-' + mod
+    return (pkg, '', '')
+
+
 def rdo_xstatic_tr(mod):
     mod = mod.replace('_', '-').replace('.', '-')
     pkg = 'python-' + mod
@@ -235,7 +241,7 @@ RDO_PKG_MAP = [
               'neutron-fwaas', 'neutron-lbaas', 'neutron-vpnaas',
               'nova', 'octavia', 'rally', 'sahara', 'swift',
               'Tempest', 'tripleo-common', 'trove', 'tuskar',
-              'vitrage', 'watcher', 'zaqar'],
+              'vitrage', 'watcher', 'zaqar', 'zun'],
         pkgfun=openstack_prefix_tr),
     # Horizon plugins (normalized to openstack-<project>-ui)
     RegexRule(pattern=r'\w+-(dashboard|ui)', pkgfun=rdo_horizon_plugins_tr),
@@ -261,7 +267,7 @@ SUSE_PKG_MAP = [
               'monasca-notification', 'monasca-persister',
               'monasca-transform', 'neutron', 'nova', 'rally',
               'sahara', 'swift', 'Tempest', 'trove', 'tuskar',
-              'watcher', 'zaqar'],
+              'watcher', 'zaqar', 'zun'],
         pkgfun=openstack_prefix_tr),
     # OpenStack clients
     MultiRule(
@@ -271,7 +277,7 @@ SUSE_PKG_MAP = [
             'freezer', 'heat', 'glance', 'glare', 'ironic',
             'ironic-inspector-', 'karbor', 'k8s', 'keystone',
             'magnum', 'manila', 'masakari', 'mistral', 'monasca',
-            'murano', 'nimble', 'neutron', 'nova', 'oneview',
+            'murano', 'nimble', 'neutron', 'nova', 'octavia', 'oneview',
             'openstack', 'qinling', 'sahara', 'scci', 'searchlight', 'senlin',
             'smaug', 'solum', 'swift', 'tacker', 'tripleo', 'trove',
             'vitrage', 'watcher', 'zaqar')],
@@ -288,14 +294,7 @@ SUSE_PKG_MAP = [
     SingleRule('monasca-ui', 'openstack-horizon-plugin-monasca-ui'),
     SingleRule('murano-dashboard', 'openstack-horizon-plugin-murano-ui'),
     SingleRule('networking-vsphere', 'openstack-neutron-vsphere'),
-    SingleRule('neutron-fwaas-dashboard',
-               'openstack-horizon-plugin-neutron-fwaas-ui'),
-    SingleRule('neutron-lbaas-dashboard',
-               'openstack-horizon-plugin-neutron-lbaas-ui'),
-    SingleRule('neutron-vpnaas-dashboard',
-               'openstack-horizon-plugin-neutron-vpnaas-ui'),
-    SingleRule('sahara-dashboard', 'openstack-horizon-plugin-sahara-ui'),
-    SingleRule('trove-dashboard', 'openstack-horizon-plugin-trove-ui'),
+    RegexRule(pattern=r'\w+-(dashboard|ui)', pkgfun=suse_horizon_plugins_tr),
 ]
 
 UBUNTU_PKG_MAP = [
@@ -316,10 +315,10 @@ UBUNTU_PKG_MAP = [
             'designate', 'fuel', 'heat', 'glance', 'ironic',
             'karbor',  'keystone',
             'magnum', 'manila', 'masakari', 'mistral', 'monasca',
-            'murano', 'neutron', 'nova',
+            'murano', 'neutron', 'nova', 'octavia',
             'openstack', 'qinling', 'sahara',
             'senlin', 'swift',
-            'trove',  'zaqar')],
+            'trove',  'zaqar', 'zun')],
         pkgfun=same_name_python_subst_python3),
 
 ]
